OboNormalizer
=============

.. currentmodule:: pyobo

.. autoclass:: OboNormalizer
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~OboNormalizer.normalize

   .. rubric:: Methods Documentation

   .. automethod:: normalize
